@@ -166,7 +166,7 @@ do_content_length_framing_test (void)
 	SoupURI *request_uri;
 	goffset declared_length;
 
-	debug_printf (1, "\nInvalid Content-Length framing tests\n");
+	g_test_bug ("611481");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 
@@ -353,7 +353,7 @@ do_persistent_connection_timeout_test (void)
 {
 	SoupSession *session;
 
-	debug_printf (1, "\nUnexpected timing out of persistent connections\n");
+	g_test_bug ("631525");
 
 	debug_printf (1, "  Async session, message API\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
@@ -475,7 +475,7 @@ do_max_conns_test (void)
 {
 	SoupSession *session;
 
-	debug_printf (1, "\nExceeding max-conns\n");
+	g_test_bug ("634422");
 
 	debug_printf (1, "  Async session\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC,
@@ -554,7 +554,7 @@ do_non_persistent_connection_test (void)
 {
 	SoupSession *session;
 
-	debug_printf (1, "\nNon-persistent connections are closed immediately\n");
+	g_test_bug ("578990");
 
 	debug_printf (1, "  Async session\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
@@ -608,8 +608,6 @@ do_non_idempotent_connection_test (void)
 {
 	SoupSession *session;
 
-	debug_printf (1, "\nNon-idempotent methods are always sent on new connections\n");
-
 	debug_printf (1, "  Async session\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	do_non_idempotent_test_for_session (session);
@@ -724,8 +722,6 @@ do_connection_state_test (void)
 
 	SOUP_TEST_SKIP_IF_NO_APACHE;
 
-	debug_printf (1, "\nConnection states\n");
-
 	debug_printf (1, "  Async session\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	do_connection_state_test_for_session (session);
@@ -834,8 +830,6 @@ do_connection_event_test (void)
 
 	SOUP_TEST_SKIP_IF_NO_APACHE;
 
-	debug_printf (1, "\nConnection events\n");
-
 	debug_printf (1, "  Async session\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	do_connection_event_test_for_session (session);
