@@ -91,7 +91,6 @@ server_callback (SoupServer *server, SoupMessage *msg,
 
 /* Host header handling: client must be able to override the default
  * value, server must be able to recognize different Host values.
- * #539803.
  */
 static void
 do_host_test (void)
@@ -99,7 +98,7 @@ do_host_test (void)
 	SoupSession *session;
 	SoupMessage *one, *two;
 
-	debug_printf (1, "Host handling\n");
+	g_test_bug ("539803");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_SYNC, NULL);
 
@@ -123,7 +122,7 @@ do_host_test (void)
 
 /* Dropping the application's ref on the session from a callback
  * should not cause the session to be freed at an incorrect time.
- * (This test will crash if it fails.) #533473
+ * (This test will crash if it fails.)
  */
 static void
 cu_one_completed (SoupSession *session, SoupMessage *msg, gpointer loop)
@@ -158,7 +157,7 @@ do_callback_unref_test (void)
 	GMainLoop *loop;
 	char *bad_uri;
 
-	debug_printf (1, "\nCallback unref handling (msg api)\n");
+	g_test_bug ("533473");
 
 	/* Get a guaranteed-bad URI */
 	addr = soup_address_new ("127.0.0.1", SOUP_ADDRESS_ANY_PORT);
@@ -252,8 +251,6 @@ do_callback_unref_req_test (void)
 	GMainLoop *loop;
 	char *bad_uri;
 
-	debug_printf (1, "\nCallback unref handling (request api)\n");
-
 	/* Get a guaranteed-bad URI */
 	addr = soup_address_new ("127.0.0.1", SOUP_ADDRESS_ANY_PORT);
 	soup_address_resolve_sync (addr, NULL);
@@ -307,7 +304,6 @@ do_callback_unref_req_test (void)
 
 /* SoupSession should clean up all signal handlers on a message after
  * it is finished, allowing the message to be reused if desired.
- * #559054
  */
 static void
 ensure_no_signal_handlers (SoupMessage *msg, guint *signal_ids, guint n_signal_ids)
@@ -343,7 +339,7 @@ do_msg_reuse_test (void)
 	SoupURI *uri;
 	guint *signal_ids, n_signal_ids;
 
-	debug_printf (1, "\nSoupMessage reuse\n");
+	g_test_bug ("559054");
 
 	signal_ids = g_signal_list_ids (SOUP_TYPE_MESSAGE, &n_signal_ids);
 
@@ -383,7 +379,7 @@ do_msg_reuse_test (void)
 	g_free (signal_ids);
 }
 
-/* Handle unexpectedly-early aborts. #596074, #618641 */
+/* Handle unexpectedly-early aborts. */
 static void
 ea_msg_completed_one (SoupSession *session, SoupMessage *msg, gpointer loop)
 {
@@ -435,7 +431,8 @@ do_early_abort_test (void)
 	GMainContext *context;
 	GMainLoop *loop;
 
-	debug_printf (1, "\nAbort with pending connection (msg api)\n");
+	g_test_bug ("596074");
+	g_test_bug ("618641");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	msg = soup_message_new_from_uri ("GET", base_uri);
@@ -467,6 +464,8 @@ do_early_abort_test (void)
 
 	soup_test_session_abort_unref (session);
 
+	g_test_bug ("668098");
+
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	msg = soup_message_new_from_uri ("GET", base_uri);
 
@@ -537,8 +536,6 @@ do_early_abort_req_test (void)
 	GMainLoop *loop;
 	GCancellable *cancellable;
 
-	debug_printf (1, "\nAbort with pending connection (request api)\n");
-
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC,
 					 SOUP_SESSION_USE_THREAD_CONTEXT, TRUE,
 					 NULL);
@@ -620,7 +617,7 @@ do_accept_language_test (void)
 {
 	const char *orig_language;
 
-	debug_printf (1, "\nAutomatic Accept-Language processing\n");
+	g_test_bug ("602547");
 
 	orig_language = g_getenv ("LANGUAGE");
 	do_one_accept_language_test ("C", "en");
@@ -705,7 +702,8 @@ do_cancel_while_reading_test (void)
 {
 	SoupSession *session;
 
-	debug_printf (1, "\nCancelling message while reading response (msg api)\n");
+	g_test_bug ("637741");
+	g_test_bug ("676038");
 
 	debug_printf (1, "  Async session\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
@@ -741,12 +739,13 @@ do_cancel_while_reading_req_test_for_session (SoupSession *session,
 }
 
 static void
-do_cancel_while_reading_req_test (void)
+do_cancel_while_reading_immediate_req_test (void)
 {
 	SoupSession *session;
 	guint flags;
 
-	debug_printf (1, "\nCancelling (immediately) message while reading response (request api)\n");
+	g_test_bug ("692310");
+
 	flags = SOUP_TEST_REQUEST_CANCEL_CANCELLABLE | SOUP_TEST_REQUEST_CANCEL_IMMEDIATE;
 
 	debug_printf (1, "  Async session\n");
@@ -761,8 +760,14 @@ do_cancel_while_reading_req_test (void)
 					 NULL);
 	do_cancel_while_reading_req_test_for_session (session, flags);
 	soup_test_session_abort_unref (session);
+}
+
+static void
+do_cancel_while_reading_delayed_req_test (void)
+{
+	SoupSession *session;
+	guint flags;
 
-	debug_printf (1, "\nCancelling (after 100ms) message while reading response (request api)\n");
 	flags = SOUP_TEST_REQUEST_CANCEL_CANCELLABLE | SOUP_TEST_REQUEST_CANCEL_SOON;
 
 	debug_printf (1, "  Async session\n");
@@ -777,8 +782,16 @@ do_cancel_while_reading_req_test (void)
 					 NULL);
 	do_cancel_while_reading_req_test_for_session (session, flags);
 	soup_test_session_abort_unref (session);
+}
+
+static void
+do_cancel_while_reading_preemptive_req_test (void)
+{
+	SoupSession *session;
+	guint flags;
+
+	g_test_bug ("637039");
 
-	debug_printf (1, "\nCancelling (preemptively) message while reading response (request api)\n");
 	flags = SOUP_TEST_REQUEST_CANCEL_CANCELLABLE | SOUP_TEST_REQUEST_CANCEL_PREEMPTIVE;
 
 	debug_printf (1, "  Async session\n");
@@ -827,8 +840,6 @@ do_aliases_test (void)
 	SoupSession *session;
 	char *aliases[] = { "foo", NULL };
 
-	debug_printf (1, "\nhttp-aliases / https-aliases\n");
-
 	debug_printf (1, "  Default behavior\n");
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	do_aliases_test_for_session (session, "http");
@@ -859,7 +870,7 @@ do_idle_on_dispose_test (void)
 	SoupMessage *msg;
 	GMainContext *async_context;
 
-	debug_printf (1, "\nTesting SoupSessionAsync dispose behavior\n");
+	g_test_bug ("667364");
 
 	async_context = g_main_context_new ();
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC,
@@ -889,7 +900,7 @@ do_pause_abort_test (void)
 	SoupMessage *msg;
 	gpointer ptr;
 
-	debug_printf (1, "\nTesting paused messages don't get leaked on abort\n");
+	g_test_bug ("673905");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 
@@ -939,7 +950,9 @@ main (int argc, char **argv)
 	g_test_add_func ("/misc/early-abort/req", do_early_abort_req_test);
 	g_test_add_func ("/misc/accept-language", do_accept_language_test);
 	g_test_add_func ("/misc/cancel-while-reading/msg", do_cancel_while_reading_test);
-	g_test_add_func ("/misc/cancel-while-reading/req", do_cancel_while_reading_req_test);
+	g_test_add_func ("/misc/cancel-while-reading/req/immediate", do_cancel_while_reading_immediate_req_test);
+	g_test_add_func ("/misc/cancel-while-reading/req/delayed", do_cancel_while_reading_delayed_req_test);
+	g_test_add_func ("/misc/cancel-while-reading/req/preemptive", do_cancel_while_reading_preemptive_req_test);
 	g_test_add_func ("/misc/aliases", do_aliases_test);
 	g_test_add_func ("/misc/idle-on-dispose", do_idle_on_dispose_test);
 	g_test_add_func ("/misc/pause-abort", do_pause_abort_test);
