@@ -65,7 +65,7 @@ do_star_test (void)
 	SoupURI *star_uri;
 	const char *handled_by;
 
-	debug_printf (1, "\nOPTIONS *\n");
+	g_test_bug ("590751");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_SYNC, NULL);
 	star_uri = soup_uri_copy (base_uri);
@@ -177,7 +177,7 @@ do_server_aliases_test (void)
 	char *https_bad[] = { "http", "dav", "fred", NULL };
 	int i;
 
-	debug_printf (1, "\nserver aliases test\n");
+	g_test_bug ("703694");
 
 	for (i = 0; http_good[i]; i++)
 		do_one_server_aliases_test (base_uri, http_good[i], TRUE);
@@ -199,7 +199,7 @@ do_dot_dot_test (void)
 	SoupMessage *msg;
 	SoupURI *uri;
 
-	debug_printf (1, "\n'..' smuggling test\n");
+	g_test_bug ("667635");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_SYNC, NULL);
 
@@ -243,7 +243,7 @@ do_ipv6_test (void)
 	SoupSession *session;
 	SoupMessage *msg;
 
-	debug_printf (1, "\nIPv6 server test\n");
+	g_test_bug ("666399");
 
 	ipv6_addr = soup_address_new ("::1", SOUP_ADDRESS_ANY_PORT);
 	soup_address_resolve_sync (ipv6_addr, NULL);
